# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RequestAuthenticationDetails(object):
    """
    Details for request HTTP authentication.
    """

    #: A constant which can be used with the oauth_scheme property of a RequestAuthenticationDetails.
    #: This constant has a value of "NONE"
    OAUTH_SCHEME_NONE = "NONE"

    #: A constant which can be used with the oauth_scheme property of a RequestAuthenticationDetails.
    #: This constant has a value of "BASIC"
    OAUTH_SCHEME_BASIC = "BASIC"

    #: A constant which can be used with the auth_request_method property of a RequestAuthenticationDetails.
    #: This constant has a value of "GET"
    AUTH_REQUEST_METHOD_GET = "GET"

    #: A constant which can be used with the auth_request_method property of a RequestAuthenticationDetails.
    #: This constant has a value of "POST"
    AUTH_REQUEST_METHOD_POST = "POST"

    def __init__(self, **kwargs):
        """
        Initializes a new RequestAuthenticationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param oauth_scheme:
            The value to assign to the oauth_scheme property of this RequestAuthenticationDetails.
            Allowed values for this property are: "NONE", "BASIC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type oauth_scheme: str

        :param auth_user_name:
            The value to assign to the auth_user_name property of this RequestAuthenticationDetails.
        :type auth_user_name: str

        :param auth_user_password:
            The value to assign to the auth_user_password property of this RequestAuthenticationDetails.
        :type auth_user_password: str

        :param auth_token:
            The value to assign to the auth_token property of this RequestAuthenticationDetails.
        :type auth_token: str

        :param auth_url:
            The value to assign to the auth_url property of this RequestAuthenticationDetails.
        :type auth_url: str

        :param auth_headers:
            The value to assign to the auth_headers property of this RequestAuthenticationDetails.
        :type auth_headers: list[oci.apm_synthetics.models.Header]

        :param auth_request_method:
            The value to assign to the auth_request_method property of this RequestAuthenticationDetails.
            Allowed values for this property are: "GET", "POST", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type auth_request_method: str

        :param auth_request_post_body:
            The value to assign to the auth_request_post_body property of this RequestAuthenticationDetails.
        :type auth_request_post_body: str

        """
        self.swagger_types = {
            'oauth_scheme': 'str',
            'auth_user_name': 'str',
            'auth_user_password': 'str',
            'auth_token': 'str',
            'auth_url': 'str',
            'auth_headers': 'list[Header]',
            'auth_request_method': 'str',
            'auth_request_post_body': 'str'
        }

        self.attribute_map = {
            'oauth_scheme': 'oauthScheme',
            'auth_user_name': 'authUserName',
            'auth_user_password': 'authUserPassword',
            'auth_token': 'authToken',
            'auth_url': 'authUrl',
            'auth_headers': 'authHeaders',
            'auth_request_method': 'authRequestMethod',
            'auth_request_post_body': 'authRequestPostBody'
        }

        self._oauth_scheme = None
        self._auth_user_name = None
        self._auth_user_password = None
        self._auth_token = None
        self._auth_url = None
        self._auth_headers = None
        self._auth_request_method = None
        self._auth_request_post_body = None

    @property
    def oauth_scheme(self):
        """
        Gets the oauth_scheme of this RequestAuthenticationDetails.
        Request http oauth scheme.

        Allowed values for this property are: "NONE", "BASIC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The oauth_scheme of this RequestAuthenticationDetails.
        :rtype: str
        """
        return self._oauth_scheme

    @oauth_scheme.setter
    def oauth_scheme(self, oauth_scheme):
        """
        Sets the oauth_scheme of this RequestAuthenticationDetails.
        Request http oauth scheme.


        :param oauth_scheme: The oauth_scheme of this RequestAuthenticationDetails.
        :type: str
        """
        allowed_values = ["NONE", "BASIC"]
        if not value_allowed_none_or_none_sentinel(oauth_scheme, allowed_values):
            oauth_scheme = 'UNKNOWN_ENUM_VALUE'
        self._oauth_scheme = oauth_scheme

    @property
    def auth_user_name(self):
        """
        Gets the auth_user_name of this RequestAuthenticationDetails.
        Username for authentication.


        :return: The auth_user_name of this RequestAuthenticationDetails.
        :rtype: str
        """
        return self._auth_user_name

    @auth_user_name.setter
    def auth_user_name(self, auth_user_name):
        """
        Sets the auth_user_name of this RequestAuthenticationDetails.
        Username for authentication.


        :param auth_user_name: The auth_user_name of this RequestAuthenticationDetails.
        :type: str
        """
        self._auth_user_name = auth_user_name

    @property
    def auth_user_password(self):
        """
        Gets the auth_user_password of this RequestAuthenticationDetails.
        User password for authentication.


        :return: The auth_user_password of this RequestAuthenticationDetails.
        :rtype: str
        """
        return self._auth_user_password

    @auth_user_password.setter
    def auth_user_password(self, auth_user_password):
        """
        Sets the auth_user_password of this RequestAuthenticationDetails.
        User password for authentication.


        :param auth_user_password: The auth_user_password of this RequestAuthenticationDetails.
        :type: str
        """
        self._auth_user_password = auth_user_password

    @property
    def auth_token(self):
        """
        Gets the auth_token of this RequestAuthenticationDetails.
        Authentication token.


        :return: The auth_token of this RequestAuthenticationDetails.
        :rtype: str
        """
        return self._auth_token

    @auth_token.setter
    def auth_token(self, auth_token):
        """
        Sets the auth_token of this RequestAuthenticationDetails.
        Authentication token.


        :param auth_token: The auth_token of this RequestAuthenticationDetails.
        :type: str
        """
        self._auth_token = auth_token

    @property
    def auth_url(self):
        """
        Gets the auth_url of this RequestAuthenticationDetails.
        URL to get authetication token.


        :return: The auth_url of this RequestAuthenticationDetails.
        :rtype: str
        """
        return self._auth_url

    @auth_url.setter
    def auth_url(self, auth_url):
        """
        Sets the auth_url of this RequestAuthenticationDetails.
        URL to get authetication token.


        :param auth_url: The auth_url of this RequestAuthenticationDetails.
        :type: str
        """
        self._auth_url = auth_url

    @property
    def auth_headers(self):
        """
        Gets the auth_headers of this RequestAuthenticationDetails.
        List of authentication headers. Example: `[{\"headerName\": \"content-type\", \"headerValue\":\"json\"}]`


        :return: The auth_headers of this RequestAuthenticationDetails.
        :rtype: list[oci.apm_synthetics.models.Header]
        """
        return self._auth_headers

    @auth_headers.setter
    def auth_headers(self, auth_headers):
        """
        Sets the auth_headers of this RequestAuthenticationDetails.
        List of authentication headers. Example: `[{\"headerName\": \"content-type\", \"headerValue\":\"json\"}]`


        :param auth_headers: The auth_headers of this RequestAuthenticationDetails.
        :type: list[oci.apm_synthetics.models.Header]
        """
        self._auth_headers = auth_headers

    @property
    def auth_request_method(self):
        """
        Gets the auth_request_method of this RequestAuthenticationDetails.
        Request method.

        Allowed values for this property are: "GET", "POST", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The auth_request_method of this RequestAuthenticationDetails.
        :rtype: str
        """
        return self._auth_request_method

    @auth_request_method.setter
    def auth_request_method(self, auth_request_method):
        """
        Sets the auth_request_method of this RequestAuthenticationDetails.
        Request method.


        :param auth_request_method: The auth_request_method of this RequestAuthenticationDetails.
        :type: str
        """
        allowed_values = ["GET", "POST"]
        if not value_allowed_none_or_none_sentinel(auth_request_method, allowed_values):
            auth_request_method = 'UNKNOWN_ENUM_VALUE'
        self._auth_request_method = auth_request_method

    @property
    def auth_request_post_body(self):
        """
        Gets the auth_request_post_body of this RequestAuthenticationDetails.
        Request post body.


        :return: The auth_request_post_body of this RequestAuthenticationDetails.
        :rtype: str
        """
        return self._auth_request_post_body

    @auth_request_post_body.setter
    def auth_request_post_body(self, auth_request_post_body):
        """
        Sets the auth_request_post_body of this RequestAuthenticationDetails.
        Request post body.


        :param auth_request_post_body: The auth_request_post_body of this RequestAuthenticationDetails.
        :type: str
        """
        self._auth_request_post_body = auth_request_post_body

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RegistryMetadata(object):
    """
    Information about the object and its parent.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RegistryMetadata object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param aggregator_key:
            The value to assign to the aggregator_key property of this RegistryMetadata.
        :type aggregator_key: str

        :param labels:
            The value to assign to the labels property of this RegistryMetadata.
        :type labels: list[str]

        :param registry_version:
            The value to assign to the registry_version property of this RegistryMetadata.
        :type registry_version: int

        :param key:
            The value to assign to the key property of this RegistryMetadata.
        :type key: str

        :param is_favorite:
            The value to assign to the is_favorite property of this RegistryMetadata.
        :type is_favorite: bool

        """
        self.swagger_types = {
            'aggregator_key': 'str',
            'labels': 'list[str]',
            'registry_version': 'int',
            'key': 'str',
            'is_favorite': 'bool'
        }

        self.attribute_map = {
            'aggregator_key': 'aggregatorKey',
            'labels': 'labels',
            'registry_version': 'registryVersion',
            'key': 'key',
            'is_favorite': 'isFavorite'
        }

        self._aggregator_key = None
        self._labels = None
        self._registry_version = None
        self._key = None
        self._is_favorite = None

    @property
    def aggregator_key(self):
        """
        Gets the aggregator_key of this RegistryMetadata.
        The owning object's key for this object.


        :return: The aggregator_key of this RegistryMetadata.
        :rtype: str
        """
        return self._aggregator_key

    @aggregator_key.setter
    def aggregator_key(self, aggregator_key):
        """
        Sets the aggregator_key of this RegistryMetadata.
        The owning object's key for this object.


        :param aggregator_key: The aggregator_key of this RegistryMetadata.
        :type: str
        """
        self._aggregator_key = aggregator_key

    @property
    def labels(self):
        """
        Gets the labels of this RegistryMetadata.
        Labels are keywords or labels that you can add to data assets, dataflows etc. You can define your own labels and use them to categorize content.


        :return: The labels of this RegistryMetadata.
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """
        Sets the labels of this RegistryMetadata.
        Labels are keywords or labels that you can add to data assets, dataflows etc. You can define your own labels and use them to categorize content.


        :param labels: The labels of this RegistryMetadata.
        :type: list[str]
        """
        self._labels = labels

    @property
    def registry_version(self):
        """
        Gets the registry_version of this RegistryMetadata.
        The registry version.


        :return: The registry_version of this RegistryMetadata.
        :rtype: int
        """
        return self._registry_version

    @registry_version.setter
    def registry_version(self, registry_version):
        """
        Sets the registry_version of this RegistryMetadata.
        The registry version.


        :param registry_version: The registry_version of this RegistryMetadata.
        :type: int
        """
        self._registry_version = registry_version

    @property
    def key(self):
        """
        Gets the key of this RegistryMetadata.
        The identifying key for the object.


        :return: The key of this RegistryMetadata.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this RegistryMetadata.
        The identifying key for the object.


        :param key: The key of this RegistryMetadata.
        :type: str
        """
        self._key = key

    @property
    def is_favorite(self):
        """
        Gets the is_favorite of this RegistryMetadata.
        Specifies whether this object is a favorite or not.


        :return: The is_favorite of this RegistryMetadata.
        :rtype: bool
        """
        return self._is_favorite

    @is_favorite.setter
    def is_favorite(self, is_favorite):
        """
        Sets the is_favorite of this RegistryMetadata.
        Specifies whether this object is a favorite or not.


        :param is_favorite: The is_favorite of this RegistryMetadata.
        :type: bool
        """
        self._is_favorite = is_favorite

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .secret_rule import SecretRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecretExpiryRule(SecretRule):
    """
    A rule that helps enforce the expiration of a secret's contents.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SecretExpiryRule object with values from keyword arguments. The default value of the :py:attr:`~oci.vault.models.SecretExpiryRule.rule_type` attribute
        of this class is ``SECRET_EXPIRY_RULE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rule_type:
            The value to assign to the rule_type property of this SecretExpiryRule.
            Allowed values for this property are: "SECRET_EXPIRY_RULE", "SECRET_REUSE_RULE"
        :type rule_type: str

        :param secret_version_expiry_interval:
            The value to assign to the secret_version_expiry_interval property of this SecretExpiryRule.
        :type secret_version_expiry_interval: str

        :param time_of_absolute_expiry:
            The value to assign to the time_of_absolute_expiry property of this SecretExpiryRule.
        :type time_of_absolute_expiry: datetime

        :param is_secret_content_retrieval_blocked_on_expiry:
            The value to assign to the is_secret_content_retrieval_blocked_on_expiry property of this SecretExpiryRule.
        :type is_secret_content_retrieval_blocked_on_expiry: bool

        """
        self.swagger_types = {
            'rule_type': 'str',
            'secret_version_expiry_interval': 'str',
            'time_of_absolute_expiry': 'datetime',
            'is_secret_content_retrieval_blocked_on_expiry': 'bool'
        }

        self.attribute_map = {
            'rule_type': 'ruleType',
            'secret_version_expiry_interval': 'secretVersionExpiryInterval',
            'time_of_absolute_expiry': 'timeOfAbsoluteExpiry',
            'is_secret_content_retrieval_blocked_on_expiry': 'isSecretContentRetrievalBlockedOnExpiry'
        }

        self._rule_type = None
        self._secret_version_expiry_interval = None
        self._time_of_absolute_expiry = None
        self._is_secret_content_retrieval_blocked_on_expiry = None
        self._rule_type = 'SECRET_EXPIRY_RULE'

    @property
    def secret_version_expiry_interval(self):
        """
        Gets the secret_version_expiry_interval of this SecretExpiryRule.
        A property indicating how long the secret contents will be considered valid, expressed in
        `ISO 8601`__ format. The secret needs to be
        updated when the secret content expires. No enforcement mechanism exists at this time, but audit logs
        record the expiration on the appropriate date, according to the time interval specified in the rule.
        The timer resets after you update the secret contents.
        The minimum value is 1 day and the maximum value is 90 days for this property. Currently, only intervals expressed in days are supported.
        For example, pass `P3D` to have the secret version expire every 3 days.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :return: The secret_version_expiry_interval of this SecretExpiryRule.
        :rtype: str
        """
        return self._secret_version_expiry_interval

    @secret_version_expiry_interval.setter
    def secret_version_expiry_interval(self, secret_version_expiry_interval):
        """
        Sets the secret_version_expiry_interval of this SecretExpiryRule.
        A property indicating how long the secret contents will be considered valid, expressed in
        `ISO 8601`__ format. The secret needs to be
        updated when the secret content expires. No enforcement mechanism exists at this time, but audit logs
        record the expiration on the appropriate date, according to the time interval specified in the rule.
        The timer resets after you update the secret contents.
        The minimum value is 1 day and the maximum value is 90 days for this property. Currently, only intervals expressed in days are supported.
        For example, pass `P3D` to have the secret version expire every 3 days.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :param secret_version_expiry_interval: The secret_version_expiry_interval of this SecretExpiryRule.
        :type: str
        """
        self._secret_version_expiry_interval = secret_version_expiry_interval

    @property
    def time_of_absolute_expiry(self):
        """
        Gets the time_of_absolute_expiry of this SecretExpiryRule.
        An optional property indicating the absolute time when this secret will expire, expressed in `RFC 3339`__ timestamp format.
        The minimum number of days from current time is 1 day and the maximum number of days from current time is 365 days.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_absolute_expiry of this SecretExpiryRule.
        :rtype: datetime
        """
        return self._time_of_absolute_expiry

    @time_of_absolute_expiry.setter
    def time_of_absolute_expiry(self, time_of_absolute_expiry):
        """
        Sets the time_of_absolute_expiry of this SecretExpiryRule.
        An optional property indicating the absolute time when this secret will expire, expressed in `RFC 3339`__ timestamp format.
        The minimum number of days from current time is 1 day and the maximum number of days from current time is 365 days.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_absolute_expiry: The time_of_absolute_expiry of this SecretExpiryRule.
        :type: datetime
        """
        self._time_of_absolute_expiry = time_of_absolute_expiry

    @property
    def is_secret_content_retrieval_blocked_on_expiry(self):
        """
        Gets the is_secret_content_retrieval_blocked_on_expiry of this SecretExpiryRule.
        A property indicating whether to block retrieval of the secret content, on expiry. The default is false.
        If the secret has already expired and you would like to retrieve the secret contents,
        you need to edit the secret rule to disable this property, to allow reading the secret content.


        :return: The is_secret_content_retrieval_blocked_on_expiry of this SecretExpiryRule.
        :rtype: bool
        """
        return self._is_secret_content_retrieval_blocked_on_expiry

    @is_secret_content_retrieval_blocked_on_expiry.setter
    def is_secret_content_retrieval_blocked_on_expiry(self, is_secret_content_retrieval_blocked_on_expiry):
        """
        Sets the is_secret_content_retrieval_blocked_on_expiry of this SecretExpiryRule.
        A property indicating whether to block retrieval of the secret content, on expiry. The default is false.
        If the secret has already expired and you would like to retrieve the secret contents,
        you need to edit the secret rule to disable this property, to allow reading the secret content.


        :param is_secret_content_retrieval_blocked_on_expiry: The is_secret_content_retrieval_blocked_on_expiry of this SecretExpiryRule.
        :type: bool
        """
        self._is_secret_content_retrieval_blocked_on_expiry = is_secret_content_retrieval_blocked_on_expiry

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpgradeDatabaseDetails(object):
    """
    Details for upgrading a database to a specific Oracle Database version.
    """

    #: A constant which can be used with the action property of a UpgradeDatabaseDetails.
    #: This constant has a value of "PRECHECK"
    ACTION_PRECHECK = "PRECHECK"

    #: A constant which can be used with the action property of a UpgradeDatabaseDetails.
    #: This constant has a value of "UPGRADE"
    ACTION_UPGRADE = "UPGRADE"

    #: A constant which can be used with the action property of a UpgradeDatabaseDetails.
    #: This constant has a value of "ROLLBACK"
    ACTION_ROLLBACK = "ROLLBACK"

    def __init__(self, **kwargs):
        """
        Initializes a new UpgradeDatabaseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action:
            The value to assign to the action property of this UpgradeDatabaseDetails.
            Allowed values for this property are: "PRECHECK", "UPGRADE", "ROLLBACK"
        :type action: str

        :param database_upgrade_source_details:
            The value to assign to the database_upgrade_source_details property of this UpgradeDatabaseDetails.
        :type database_upgrade_source_details: oci.database.models.DatabaseUpgradeSourceBase

        """
        self.swagger_types = {
            'action': 'str',
            'database_upgrade_source_details': 'DatabaseUpgradeSourceBase'
        }

        self.attribute_map = {
            'action': 'action',
            'database_upgrade_source_details': 'databaseUpgradeSourceDetails'
        }

        self._action = None
        self._database_upgrade_source_details = None

    @property
    def action(self):
        """
        **[Required]** Gets the action of this UpgradeDatabaseDetails.
        The database upgrade action.

        Allowed values for this property are: "PRECHECK", "UPGRADE", "ROLLBACK"


        :return: The action of this UpgradeDatabaseDetails.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this UpgradeDatabaseDetails.
        The database upgrade action.


        :param action: The action of this UpgradeDatabaseDetails.
        :type: str
        """
        allowed_values = ["PRECHECK", "UPGRADE", "ROLLBACK"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            raise ValueError(
                "Invalid value for `action`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._action = action

    @property
    def database_upgrade_source_details(self):
        """
        Gets the database_upgrade_source_details of this UpgradeDatabaseDetails.

        :return: The database_upgrade_source_details of this UpgradeDatabaseDetails.
        :rtype: oci.database.models.DatabaseUpgradeSourceBase
        """
        return self._database_upgrade_source_details

    @database_upgrade_source_details.setter
    def database_upgrade_source_details(self, database_upgrade_source_details):
        """
        Sets the database_upgrade_source_details of this UpgradeDatabaseDetails.

        :param database_upgrade_source_details: The database_upgrade_source_details of this UpgradeDatabaseDetails.
        :type: oci.database.models.DatabaseUpgradeSourceBase
        """
        self._database_upgrade_source_details = database_upgrade_source_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .affected_resource import AffectedResource
from .announcement import Announcement
from .announcement_summary import AnnouncementSummary
from .announcement_user_status_details import AnnouncementUserStatusDetails
from .announcements_collection import AnnouncementsCollection
from .announcements_preferences import AnnouncementsPreferences
from .announcements_preferences_summary import AnnouncementsPreferencesSummary
from .base_announcement import BaseAnnouncement
from .base_announcements_preferences import BaseAnnouncementsPreferences
from .base_create_announcements_preferences_details import BaseCreateAnnouncementsPreferencesDetails
from .create_announcements_preferences_details import CreateAnnouncementsPreferencesDetails
from .model_property import ModelProperty
from .update_announcements_preferences_details import UpdateAnnouncementsPreferencesDetails

# Maps type names to classes for announcements_service services.
announcements_service_type_mapping = {
    "AffectedResource": AffectedResource,
    "Announcement": Announcement,
    "AnnouncementSummary": AnnouncementSummary,
    "AnnouncementUserStatusDetails": AnnouncementUserStatusDetails,
    "AnnouncementsCollection": AnnouncementsCollection,
    "AnnouncementsPreferences": AnnouncementsPreferences,
    "AnnouncementsPreferencesSummary": AnnouncementsPreferencesSummary,
    "BaseAnnouncement": BaseAnnouncement,
    "BaseAnnouncementsPreferences": BaseAnnouncementsPreferences,
    "BaseCreateAnnouncementsPreferencesDetails": BaseCreateAnnouncementsPreferencesDetails,
    "CreateAnnouncementsPreferencesDetails": CreateAnnouncementsPreferencesDetails,
    "ModelProperty": ModelProperty,
    "UpdateAnnouncementsPreferencesDetails": UpdateAnnouncementsPreferencesDetails
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryableFieldDescription(object):
    """
    An individual field that can be used as part of a query filter.
    """

    #: A constant which can be used with the field_type property of a QueryableFieldDescription.
    #: This constant has a value of "IDENTIFIER"
    FIELD_TYPE_IDENTIFIER = "IDENTIFIER"

    #: A constant which can be used with the field_type property of a QueryableFieldDescription.
    #: This constant has a value of "STRING"
    FIELD_TYPE_STRING = "STRING"

    #: A constant which can be used with the field_type property of a QueryableFieldDescription.
    #: This constant has a value of "INTEGER"
    FIELD_TYPE_INTEGER = "INTEGER"

    #: A constant which can be used with the field_type property of a QueryableFieldDescription.
    #: This constant has a value of "RATIONAL"
    FIELD_TYPE_RATIONAL = "RATIONAL"

    #: A constant which can be used with the field_type property of a QueryableFieldDescription.
    #: This constant has a value of "BOOLEAN"
    FIELD_TYPE_BOOLEAN = "BOOLEAN"

    #: A constant which can be used with the field_type property of a QueryableFieldDescription.
    #: This constant has a value of "DATETIME"
    FIELD_TYPE_DATETIME = "DATETIME"

    #: A constant which can be used with the field_type property of a QueryableFieldDescription.
    #: This constant has a value of "IP"
    FIELD_TYPE_IP = "IP"

    #: A constant which can be used with the field_type property of a QueryableFieldDescription.
    #: This constant has a value of "OBJECT"
    FIELD_TYPE_OBJECT = "OBJECT"

    def __init__(self, **kwargs):
        """
        Initializes a new QueryableFieldDescription object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param field_type:
            The value to assign to the field_type property of this QueryableFieldDescription.
            Allowed values for this property are: "IDENTIFIER", "STRING", "INTEGER", "RATIONAL", "BOOLEAN", "DATETIME", "IP", "OBJECT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type field_type: str

        :param field_name:
            The value to assign to the field_name property of this QueryableFieldDescription.
        :type field_name: str

        :param is_array:
            The value to assign to the is_array property of this QueryableFieldDescription.
        :type is_array: bool

        :param object_properties:
            The value to assign to the object_properties property of this QueryableFieldDescription.
        :type object_properties: list[oci.resource_search.models.QueryableFieldDescription]

        """
        self.swagger_types = {
            'field_type': 'str',
            'field_name': 'str',
            'is_array': 'bool',
            'object_properties': 'list[QueryableFieldDescription]'
        }

        self.attribute_map = {
            'field_type': 'fieldType',
            'field_name': 'fieldName',
            'is_array': 'isArray',
            'object_properties': 'objectProperties'
        }

        self._field_type = None
        self._field_name = None
        self._is_array = None
        self._object_properties = None

    @property
    def field_type(self):
        """
        **[Required]** Gets the field_type of this QueryableFieldDescription.
        The type of the field, which dictates what semantics and query constraints you can use when searching or querying.

        Allowed values for this property are: "IDENTIFIER", "STRING", "INTEGER", "RATIONAL", "BOOLEAN", "DATETIME", "IP", "OBJECT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The field_type of this QueryableFieldDescription.
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """
        Sets the field_type of this QueryableFieldDescription.
        The type of the field, which dictates what semantics and query constraints you can use when searching or querying.


        :param field_type: The field_type of this QueryableFieldDescription.
        :type: str
        """
        allowed_values = ["IDENTIFIER", "STRING", "INTEGER", "RATIONAL", "BOOLEAN", "DATETIME", "IP", "OBJECT"]
        if not value_allowed_none_or_none_sentinel(field_type, allowed_values):
            field_type = 'UNKNOWN_ENUM_VALUE'
        self._field_type = field_type

    @property
    def field_name(self):
        """
        **[Required]** Gets the field_name of this QueryableFieldDescription.
        The name of the field to use when constructing the query. Field names are present for all types except `OBJECT`.


        :return: The field_name of this QueryableFieldDescription.
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """
        Sets the field_name of this QueryableFieldDescription.
        The name of the field to use when constructing the query. Field names are present for all types except `OBJECT`.


        :param field_name: The field_name of this QueryableFieldDescription.
        :type: str
        """
        self._field_name = field_name

    @property
    def is_array(self):
        """
        Gets the is_array of this QueryableFieldDescription.
        Indicates that this field is actually an array of the specified field type.


        :return: The is_array of this QueryableFieldDescription.
        :rtype: bool
        """
        return self._is_array

    @is_array.setter
    def is_array(self, is_array):
        """
        Sets the is_array of this QueryableFieldDescription.
        Indicates that this field is actually an array of the specified field type.


        :param is_array: The is_array of this QueryableFieldDescription.
        :type: bool
        """
        self._is_array = is_array

    @property
    def object_properties(self):
        """
        Gets the object_properties of this QueryableFieldDescription.
        If the field type is `OBJECT`, then this property will provide all the individual properties of the object that can
        be queried.


        :return: The object_properties of this QueryableFieldDescription.
        :rtype: list[oci.resource_search.models.QueryableFieldDescription]
        """
        return self._object_properties

    @object_properties.setter
    def object_properties(self, object_properties):
        """
        Sets the object_properties of this QueryableFieldDescription.
        If the field type is `OBJECT`, then this property will provide all the individual properties of the object that can
        be queried.


        :param object_properties: The object_properties of this QueryableFieldDescription.
        :type: list[oci.resource_search.models.QueryableFieldDescription]
        """
        self._object_properties = object_properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstancePoolPlacementSecondaryVnicSubnet(object):
    """
    The secondary VNIC object for the placement configuration for an instance pool.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstancePoolPlacementSecondaryVnicSubnet object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this InstancePoolPlacementSecondaryVnicSubnet.
        :type display_name: str

        :param subnet_id:
            The value to assign to the subnet_id property of this InstancePoolPlacementSecondaryVnicSubnet.
        :type subnet_id: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'subnet_id': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'subnet_id': 'subnetId'
        }

        self._display_name = None
        self._subnet_id = None

    @property
    def display_name(self):
        """
        Gets the display_name of this InstancePoolPlacementSecondaryVnicSubnet.
        The display name of the VNIC. This is also use to match against the instance configuration defined
        secondary VNIC.


        :return: The display_name of this InstancePoolPlacementSecondaryVnicSubnet.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this InstancePoolPlacementSecondaryVnicSubnet.
        The display name of the VNIC. This is also use to match against the instance configuration defined
        secondary VNIC.


        :param display_name: The display_name of this InstancePoolPlacementSecondaryVnicSubnet.
        :type: str
        """
        self._display_name = display_name

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this InstancePoolPlacementSecondaryVnicSubnet.
        The subnet `OCID`__ for the secondary VNIC.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this InstancePoolPlacementSecondaryVnicSubnet.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this InstancePoolPlacementSecondaryVnicSubnet.
        The subnet `OCID`__ for the secondary VNIC.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this InstancePoolPlacementSecondaryVnicSubnet.
        :type: str
        """
        self._subnet_id = subnet_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .attach_volume_details import AttachVolumeDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AttachIScsiVolumeDetails(AttachVolumeDetails):
    """
    AttachIScsiVolumeDetails model.
    """

    #: A constant which can be used with the encryption_in_transit_type property of a AttachIScsiVolumeDetails.
    #: This constant has a value of "NONE"
    ENCRYPTION_IN_TRANSIT_TYPE_NONE = "NONE"

    #: A constant which can be used with the encryption_in_transit_type property of a AttachIScsiVolumeDetails.
    #: This constant has a value of "BM_ENCRYPTION_IN_TRANSIT"
    ENCRYPTION_IN_TRANSIT_TYPE_BM_ENCRYPTION_IN_TRANSIT = "BM_ENCRYPTION_IN_TRANSIT"

    def __init__(self, **kwargs):
        """
        Initializes a new AttachIScsiVolumeDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.AttachIScsiVolumeDetails.type` attribute
        of this class is ``iscsi`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param device:
            The value to assign to the device property of this AttachIScsiVolumeDetails.
        :type device: str

        :param display_name:
            The value to assign to the display_name property of this AttachIScsiVolumeDetails.
        :type display_name: str

        :param instance_id:
            The value to assign to the instance_id property of this AttachIScsiVolumeDetails.
        :type instance_id: str

        :param is_read_only:
            The value to assign to the is_read_only property of this AttachIScsiVolumeDetails.
        :type is_read_only: bool

        :param is_shareable:
            The value to assign to the is_shareable property of this AttachIScsiVolumeDetails.
        :type is_shareable: bool

        :param type:
            The value to assign to the type property of this AttachIScsiVolumeDetails.
        :type type: str

        :param volume_id:
            The value to assign to the volume_id property of this AttachIScsiVolumeDetails.
        :type volume_id: str

        :param use_chap:
            The value to assign to the use_chap property of this AttachIScsiVolumeDetails.
        :type use_chap: bool

        :param encryption_in_transit_type:
            The value to assign to the encryption_in_transit_type property of this AttachIScsiVolumeDetails.
            Allowed values for this property are: "NONE", "BM_ENCRYPTION_IN_TRANSIT"
        :type encryption_in_transit_type: str

        """
        self.swagger_types = {
            'device': 'str',
            'display_name': 'str',
            'instance_id': 'str',
            'is_read_only': 'bool',
            'is_shareable': 'bool',
            'type': 'str',
            'volume_id': 'str',
            'use_chap': 'bool',
            'encryption_in_transit_type': 'str'
        }

        self.attribute_map = {
            'device': 'device',
            'display_name': 'displayName',
            'instance_id': 'instanceId',
            'is_read_only': 'isReadOnly',
            'is_shareable': 'isShareable',
            'type': 'type',
            'volume_id': 'volumeId',
            'use_chap': 'useChap',
            'encryption_in_transit_type': 'encryptionInTransitType'
        }

        self._device = None
        self._display_name = None
        self._instance_id = None
        self._is_read_only = None
        self._is_shareable = None
        self._type = None
        self._volume_id = None
        self._use_chap = None
        self._encryption_in_transit_type = None
        self._type = 'iscsi'

    @property
    def use_chap(self):
        """
        Gets the use_chap of this AttachIScsiVolumeDetails.
        Whether to use CHAP authentication for the volume attachment. Defaults to false.


        :return: The use_chap of this AttachIScsiVolumeDetails.
        :rtype: bool
        """
        return self._use_chap

    @use_chap.setter
    def use_chap(self, use_chap):
        """
        Sets the use_chap of this AttachIScsiVolumeDetails.
        Whether to use CHAP authentication for the volume attachment. Defaults to false.


        :param use_chap: The use_chap of this AttachIScsiVolumeDetails.
        :type: bool
        """
        self._use_chap = use_chap

    @property
    def encryption_in_transit_type(self):
        """
        Gets the encryption_in_transit_type of this AttachIScsiVolumeDetails.
        Refer the top-level definition of encryptionInTransitType.
        The default value is NONE.

        Allowed values for this property are: "NONE", "BM_ENCRYPTION_IN_TRANSIT"


        :return: The encryption_in_transit_type of this AttachIScsiVolumeDetails.
        :rtype: str
        """
        return self._encryption_in_transit_type

    @encryption_in_transit_type.setter
    def encryption_in_transit_type(self, encryption_in_transit_type):
        """
        Sets the encryption_in_transit_type of this AttachIScsiVolumeDetails.
        Refer the top-level definition of encryptionInTransitType.
        The default value is NONE.


        :param encryption_in_transit_type: The encryption_in_transit_type of this AttachIScsiVolumeDetails.
        :type: str
        """
        allowed_values = ["NONE", "BM_ENCRYPTION_IN_TRANSIT"]
        if not value_allowed_none_or_none_sentinel(encryption_in_transit_type, allowed_values):
            raise ValueError(
                "Invalid value for `encryption_in_transit_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._encryption_in_transit_type = encryption_in_transit_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrDbSnapshotRangeSummary(object):
    """
    The summary data for a range of AWR snapshots.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AwrDbSnapshotRangeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param awr_db_id:
            The value to assign to the awr_db_id property of this AwrDbSnapshotRangeSummary.
        :type awr_db_id: str

        :param db_name:
            The value to assign to the db_name property of this AwrDbSnapshotRangeSummary.
        :type db_name: str

        :param instance_list:
            The value to assign to the instance_list property of this AwrDbSnapshotRangeSummary.
        :type instance_list: list[int]

        :param time_db_startup:
            The value to assign to the time_db_startup property of this AwrDbSnapshotRangeSummary.
        :type time_db_startup: datetime

        :param time_first_snapshot_begin:
            The value to assign to the time_first_snapshot_begin property of this AwrDbSnapshotRangeSummary.
        :type time_first_snapshot_begin: datetime

        :param time_latest_snapshot_end:
            The value to assign to the time_latest_snapshot_end property of this AwrDbSnapshotRangeSummary.
        :type time_latest_snapshot_end: datetime

        :param first_snapshot_id:
            The value to assign to the first_snapshot_id property of this AwrDbSnapshotRangeSummary.
        :type first_snapshot_id: int

        :param latest_snapshot_id:
            The value to assign to the latest_snapshot_id property of this AwrDbSnapshotRangeSummary.
        :type latest_snapshot_id: int

        :param snapshot_count:
            The value to assign to the snapshot_count property of this AwrDbSnapshotRangeSummary.
        :type snapshot_count: int

        :param snapshot_interval_in_min:
            The value to assign to the snapshot_interval_in_min property of this AwrDbSnapshotRangeSummary.
        :type snapshot_interval_in_min: int

        :param container_id:
            The value to assign to the container_id property of this AwrDbSnapshotRangeSummary.
        :type container_id: int

        :param db_version:
            The value to assign to the db_version property of this AwrDbSnapshotRangeSummary.
        :type db_version: str

        :param snapshot_timezone:
            The value to assign to the snapshot_timezone property of this AwrDbSnapshotRangeSummary.
        :type snapshot_timezone: str

        """
        self.swagger_types = {
            'awr_db_id': 'str',
            'db_name': 'str',
            'instance_list': 'list[int]',
            'time_db_startup': 'datetime',
            'time_first_snapshot_begin': 'datetime',
            'time_latest_snapshot_end': 'datetime',
            'first_snapshot_id': 'int',
            'latest_snapshot_id': 'int',
            'snapshot_count': 'int',
            'snapshot_interval_in_min': 'int',
            'container_id': 'int',
            'db_version': 'str',
            'snapshot_timezone': 'str'
        }

        self.attribute_map = {
            'awr_db_id': 'awrDbId',
            'db_name': 'dbName',
            'instance_list': 'instanceList',
            'time_db_startup': 'timeDbStartup',
            'time_first_snapshot_begin': 'timeFirstSnapshotBegin',
            'time_latest_snapshot_end': 'timeLatestSnapshotEnd',
            'first_snapshot_id': 'firstSnapshotId',
            'latest_snapshot_id': 'latestSnapshotId',
            'snapshot_count': 'snapshotCount',
            'snapshot_interval_in_min': 'snapshotIntervalInMin',
            'container_id': 'containerId',
            'db_version': 'dbVersion',
            'snapshot_timezone': 'snapshotTimezone'
        }

        self._awr_db_id = None
        self._db_name = None
        self._instance_list = None
        self._time_db_startup = None
        self._time_first_snapshot_begin = None
        self._time_latest_snapshot_end = None
        self._first_snapshot_id = None
        self._latest_snapshot_id = None
        self._snapshot_count = None
        self._snapshot_interval_in_min = None
        self._container_id = None
        self._db_version = None
        self._snapshot_timezone = None

    @property
    def awr_db_id(self):
        """
        **[Required]** Gets the awr_db_id of this AwrDbSnapshotRangeSummary.
        The internal ID of the database. The internal ID of the database is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbs

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The awr_db_id of this AwrDbSnapshotRangeSummary.
        :rtype: str
        """
        return self._awr_db_id

    @awr_db_id.setter
    def awr_db_id(self, awr_db_id):
        """
        Sets the awr_db_id of this AwrDbSnapshotRangeSummary.
        The internal ID of the database. The internal ID of the database is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbs

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param awr_db_id: The awr_db_id of this AwrDbSnapshotRangeSummary.
        :type: str
        """
        self._awr_db_id = awr_db_id

    @property
    def db_name(self):
        """
        **[Required]** Gets the db_name of this AwrDbSnapshotRangeSummary.
        The name of the database.


        :return: The db_name of this AwrDbSnapshotRangeSummary.
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """
        Sets the db_name of this AwrDbSnapshotRangeSummary.
        The name of the database.


        :param db_name: The db_name of this AwrDbSnapshotRangeSummary.
        :type: str
        """
        self._db_name = db_name

    @property
    def instance_list(self):
        """
        Gets the instance_list of this AwrDbSnapshotRangeSummary.
        The database instance numbers.


        :return: The instance_list of this AwrDbSnapshotRangeSummary.
        :rtype: list[int]
        """
        return self._instance_list

    @instance_list.setter
    def instance_list(self, instance_list):
        """
        Sets the instance_list of this AwrDbSnapshotRangeSummary.
        The database instance numbers.


        :param instance_list: The instance_list of this AwrDbSnapshotRangeSummary.
        :type: list[int]
        """
        self._instance_list = instance_list

    @property
    def time_db_startup(self):
        """
        Gets the time_db_startup of this AwrDbSnapshotRangeSummary.
        The timestamp of the database startup.


        :return: The time_db_startup of this AwrDbSnapshotRangeSummary.
        :rtype: datetime
        """
        return self._time_db_startup

    @time_db_startup.setter
    def time_db_startup(self, time_db_startup):
        """
        Sets the time_db_startup of this AwrDbSnapshotRangeSummary.
        The timestamp of the database startup.


        :param time_db_startup: The time_db_startup of this AwrDbSnapshotRangeSummary.
        :type: datetime
        """
        self._time_db_startup = time_db_startup

    @property
    def time_first_snapshot_begin(self):
        """
        Gets the time_first_snapshot_begin of this AwrDbSnapshotRangeSummary.
        The start time of the earliest snapshot.


        :return: The time_first_snapshot_begin of this AwrDbSnapshotRangeSummary.
        :rtype: datetime
        """
        return self._time_first_snapshot_begin

    @time_first_snapshot_begin.setter
    def time_first_snapshot_begin(self, time_first_snapshot_begin):
        """
        Sets the time_first_snapshot_begin of this AwrDbSnapshotRangeSummary.
        The start time of the earliest snapshot.


        :param time_first_snapshot_begin: The time_first_snapshot_begin of this AwrDbSnapshotRangeSummary.
        :type: datetime
        """
        self._time_first_snapshot_begin = time_first_snapshot_begin

    @property
    def time_latest_snapshot_end(self):
        """
        Gets the time_latest_snapshot_end of this AwrDbSnapshotRangeSummary.
        The end time of the latest snapshot.


        :return: The time_latest_snapshot_end of this AwrDbSnapshotRangeSummary.
        :rtype: datetime
        """
        return self._time_latest_snapshot_end

    @time_latest_snapshot_end.setter
    def time_latest_snapshot_end(self, time_latest_snapshot_end):
        """
        Sets the time_latest_snapshot_end of this AwrDbSnapshotRangeSummary.
        The end time of the latest snapshot.


        :param time_latest_snapshot_end: The time_latest_snapshot_end of this AwrDbSnapshotRangeSummary.
        :type: datetime
        """
        self._time_latest_snapshot_end = time_latest_snapshot_end

    @property
    def first_snapshot_id(self):
        """
        Gets the first_snapshot_id of this AwrDbSnapshotRangeSummary.
        The ID of the earliest snapshot. The snapshot ID is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbs/{awrDbId}/awrDbSnapshots

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The first_snapshot_id of this AwrDbSnapshotRangeSummary.
        :rtype: int
        """
        return self._first_snapshot_id

    @first_snapshot_id.setter
    def first_snapshot_id(self, first_snapshot_id):
        """
        Sets the first_snapshot_id of this AwrDbSnapshotRangeSummary.
        The ID of the earliest snapshot. The snapshot ID is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbs/{awrDbId}/awrDbSnapshots

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param first_snapshot_id: The first_snapshot_id of this AwrDbSnapshotRangeSummary.
        :type: int
        """
        self._first_snapshot_id = first_snapshot_id

    @property
    def latest_snapshot_id(self):
        """
        Gets the latest_snapshot_id of this AwrDbSnapshotRangeSummary.
        The ID of the latest snapshot. The snapshot ID is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbs/{awrDbId}/awrDbSnapshots

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The latest_snapshot_id of this AwrDbSnapshotRangeSummary.
        :rtype: int
        """
        return self._latest_snapshot_id

    @latest_snapshot_id.setter
    def latest_snapshot_id(self, latest_snapshot_id):
        """
        Sets the latest_snapshot_id of this AwrDbSnapshotRangeSummary.
        The ID of the latest snapshot. The snapshot ID is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbs/{awrDbId}/awrDbSnapshots

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param latest_snapshot_id: The latest_snapshot_id of this AwrDbSnapshotRangeSummary.
        :type: int
        """
        self._latest_snapshot_id = latest_snapshot_id

    @property
    def snapshot_count(self):
        """
        Gets the snapshot_count of this AwrDbSnapshotRangeSummary.
        The total number of snapshots.


        :return: The snapshot_count of this AwrDbSnapshotRangeSummary.
        :rtype: int
        """
        return self._snapshot_count

    @snapshot_count.setter
    def snapshot_count(self, snapshot_count):
        """
        Sets the snapshot_count of this AwrDbSnapshotRangeSummary.
        The total number of snapshots.


        :param snapshot_count: The snapshot_count of this AwrDbSnapshotRangeSummary.
        :type: int
        """
        self._snapshot_count = snapshot_count

    @property
    def snapshot_interval_in_min(self):
        """
        Gets the snapshot_interval_in_min of this AwrDbSnapshotRangeSummary.
        The interval time between snapshots (in minutes).


        :return: The snapshot_interval_in_min of this AwrDbSnapshotRangeSummary.
        :rtype: int
        """
        return self._snapshot_interval_in_min

    @snapshot_interval_in_min.setter
    def snapshot_interval_in_min(self, snapshot_interval_in_min):
        """
        Sets the snapshot_interval_in_min of this AwrDbSnapshotRangeSummary.
        The interval time between snapshots (in minutes).


        :param snapshot_interval_in_min: The snapshot_interval_in_min of this AwrDbSnapshotRangeSummary.
        :type: int
        """
        self._snapshot_interval_in_min = snapshot_interval_in_min

    @property
    def container_id(self):
        """
        Gets the container_id of this AwrDbSnapshotRangeSummary.
        ID of the database container. The database container ID is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbSnapshotRanges

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The container_id of this AwrDbSnapshotRangeSummary.
        :rtype: int
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """
        Sets the container_id of this AwrDbSnapshotRangeSummary.
        ID of the database container. The database container ID is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbSnapshotRanges

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param container_id: The container_id of this AwrDbSnapshotRangeSummary.
        :type: int
        """
        self._container_id = container_id

    @property
    def db_version(self):
        """
        Gets the db_version of this AwrDbSnapshotRangeSummary.
        The version of the database.


        :return: The db_version of this AwrDbSnapshotRangeSummary.
        :rtype: str
        """
        return self._db_version

    @db_version.setter
    def db_version(self, db_version):
        """
        Sets the db_version of this AwrDbSnapshotRangeSummary.
        The version of the database.


        :param db_version: The db_version of this AwrDbSnapshotRangeSummary.
        :type: str
        """
        self._db_version = db_version

    @property
    def snapshot_timezone(self):
        """
        Gets the snapshot_timezone of this AwrDbSnapshotRangeSummary.
        The time zone of the snapshot.


        :return: The snapshot_timezone of this AwrDbSnapshotRangeSummary.
        :rtype: str
        """
        return self._snapshot_timezone

    @snapshot_timezone.setter
    def snapshot_timezone(self, snapshot_timezone):
        """
        Sets the snapshot_timezone of this AwrDbSnapshotRangeSummary.
        The time zone of the snapshot.


        :param snapshot_timezone: The snapshot_timezone of this AwrDbSnapshotRangeSummary.
        :type: str
        """
        self._snapshot_timezone = snapshot_timezone

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .argument import Argument
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LiteralArgument(Argument):
    """
    QueryString argument of type literal.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LiteralArgument object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.LiteralArgument.type` attribute
        of this class is ``LITERAL`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this LiteralArgument.
            Allowed values for this property are: "FIELD", "LITERAL"
        :type type: str

        :param data_type:
            The value to assign to the data_type property of this LiteralArgument.
        :type data_type: str

        :param value:
            The value to assign to the value property of this LiteralArgument.
        :type value: object

        """
        self.swagger_types = {
            'type': 'str',
            'data_type': 'str',
            'value': 'object'
        }

        self.attribute_map = {
            'type': 'type',
            'data_type': 'dataType',
            'value': 'value'
        }

        self._type = None
        self._data_type = None
        self._value = None
        self._type = 'LITERAL'

    @property
    def data_type(self):
        """
        Gets the data_type of this LiteralArgument.
        Data type of specified literal in queryString.


        :return: The data_type of this LiteralArgument.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this LiteralArgument.
        Data type of specified literal in queryString.


        :param data_type: The data_type of this LiteralArgument.
        :type: str
        """
        self._data_type = data_type

    @property
    def value(self):
        """
        Gets the value of this LiteralArgument.
        Literal value specified in queryString.


        :return: The value of this LiteralArgument.
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this LiteralArgument.
        Literal value specified in queryString.


        :param value: The value of this LiteralArgument.
        :type: object
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TraceServiceSummary(object):
    """
    A summary of the spans in a trace by service.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TraceServiceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param span_service_name:
            The value to assign to the span_service_name property of this TraceServiceSummary.
        :type span_service_name: str

        :param total_spans:
            The value to assign to the total_spans property of this TraceServiceSummary.
        :type total_spans: int

        :param error_spans:
            The value to assign to the error_spans property of this TraceServiceSummary.
        :type error_spans: int

        """
        self.swagger_types = {
            'span_service_name': 'str',
            'total_spans': 'int',
            'error_spans': 'int'
        }

        self.attribute_map = {
            'span_service_name': 'spanServiceName',
            'total_spans': 'totalSpans',
            'error_spans': 'errorSpans'
        }

        self._span_service_name = None
        self._total_spans = None
        self._error_spans = None

    @property
    def span_service_name(self):
        """
        **[Required]** Gets the span_service_name of this TraceServiceSummary.
        Name associated with the service.


        :return: The span_service_name of this TraceServiceSummary.
        :rtype: str
        """
        return self._span_service_name

    @span_service_name.setter
    def span_service_name(self, span_service_name):
        """
        Sets the span_service_name of this TraceServiceSummary.
        Name associated with the service.


        :param span_service_name: The span_service_name of this TraceServiceSummary.
        :type: str
        """
        self._span_service_name = span_service_name

    @property
    def total_spans(self):
        """
        **[Required]** Gets the total_spans of this TraceServiceSummary.
        Number of spans for serviceName in this trace.


        :return: The total_spans of this TraceServiceSummary.
        :rtype: int
        """
        return self._total_spans

    @total_spans.setter
    def total_spans(self, total_spans):
        """
        Sets the total_spans of this TraceServiceSummary.
        Number of spans for serviceName in this trace.


        :param total_spans: The total_spans of this TraceServiceSummary.
        :type: int
        """
        self._total_spans = total_spans

    @property
    def error_spans(self):
        """
        **[Required]** Gets the error_spans of this TraceServiceSummary.
        Number of spans with errorsfor serviceName in this trace.


        :return: The error_spans of this TraceServiceSummary.
        :rtype: int
        """
        return self._error_spans

    @error_spans.setter
    def error_spans(self, error_spans):
        """
        Sets the error_spans of this TraceServiceSummary.
        Number of spans with errorsfor serviceName in this trace.


        :param error_spans: The error_spans of this TraceServiceSummary.
        :type: int
        """
        self._error_spans = error_spans

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Ipv6(object):
    """
    An *IPv6* is a conceptual term that refers to an IPv6 address and related properties.
    The `IPv6` object is the API representation of an IPv6.

    You can create and assign an IPv6 to any VNIC that is in an IPv6-enabled subnet in an
    IPv6-enabled VCN.

    **Note:** IPv6 addressing is supported for all commercial and government regions. For important
    details about IPv6 addressing in a VCN, see `IPv6 Addresses`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm
    """

    #: A constant which can be used with the lifecycle_state property of a Ipv6.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a Ipv6.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a Ipv6.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a Ipv6.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    def __init__(self, **kwargs):
        """
        Initializes a new Ipv6 object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this Ipv6.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this Ipv6.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this Ipv6.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Ipv6.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this Ipv6.
        :type id: str

        :param ip_address:
            The value to assign to the ip_address property of this Ipv6.
        :type ip_address: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Ipv6.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param subnet_id:
            The value to assign to the subnet_id property of this Ipv6.
        :type subnet_id: str

        :param time_created:
            The value to assign to the time_created property of this Ipv6.
        :type time_created: datetime

        :param vnic_id:
            The value to assign to the vnic_id property of this Ipv6.
        :type vnic_id: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'ip_address': 'str',
            'lifecycle_state': 'str',
            'subnet_id': 'str',
            'time_created': 'datetime',
            'vnic_id': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'ip_address': 'ipAddress',
            'lifecycle_state': 'lifecycleState',
            'subnet_id': 'subnetId',
            'time_created': 'timeCreated',
            'vnic_id': 'vnicId'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._ip_address = None
        self._lifecycle_state = None
        self._subnet_id = None
        self._time_created = None
        self._vnic_id = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Ipv6.
        The `OCID`__ of the compartment containing the IPv6.
        This is the same as the VNIC's compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Ipv6.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Ipv6.
        The `OCID`__ of the compartment containing the IPv6.
        This is the same as the VNIC's compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Ipv6.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Ipv6.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Ipv6.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Ipv6.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Ipv6.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this Ipv6.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :return: The display_name of this Ipv6.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Ipv6.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :param display_name: The display_name of this Ipv6.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Ipv6.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Ipv6.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Ipv6.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Ipv6.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Ipv6.
        The `OCID`__ of the IPv6.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Ipv6.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Ipv6.
        The `OCID`__ of the IPv6.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Ipv6.
        :type: str
        """
        self._id = id

    @property
    def ip_address(self):
        """
        **[Required]** Gets the ip_address of this Ipv6.
        The IPv6 address of the `IPv6` object. The address is within the IPv6 CIDR block of the VNIC's subnet
        (see the `ipv6CidrBlock` attribute for the :class:`Subnet` object.

        Example: `2001:0db8:0123:1111:abcd:ef01:2345:6789`


        :return: The ip_address of this Ipv6.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this Ipv6.
        The IPv6 address of the `IPv6` object. The address is within the IPv6 CIDR block of the VNIC's subnet
        (see the `ipv6CidrBlock` attribute for the :class:`Subnet` object.

        Example: `2001:0db8:0123:1111:abcd:ef01:2345:6789`


        :param ip_address: The ip_address of this Ipv6.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Ipv6.
        The IPv6's current state.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Ipv6.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Ipv6.
        The IPv6's current state.


        :param lifecycle_state: The lifecycle_state of this Ipv6.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this Ipv6.
        The `OCID`__ of the subnet the VNIC is in.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this Ipv6.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this Ipv6.
        The `OCID`__ of the subnet the VNIC is in.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this Ipv6.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Ipv6.
        The date and time the IPv6 was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Ipv6.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Ipv6.
        The date and time the IPv6 was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Ipv6.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def vnic_id(self):
        """
        **[Required]** Gets the vnic_id of this Ipv6.
        The `OCID`__ of the VNIC the IPv6 is assigned to.
        The VNIC and IPv6 must be in the same subnet.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The vnic_id of this Ipv6.
        :rtype: str
        """
        return self._vnic_id

    @vnic_id.setter
    def vnic_id(self, vnic_id):
        """
        Sets the vnic_id of this Ipv6.
        The `OCID`__ of the VNIC the IPv6 is assigned to.
        The VNIC and IPv6 must be in the same subnet.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param vnic_id: The vnic_id of this Ipv6.
        :type: str
        """
        self._vnic_id = vnic_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Link(object):
    """
    A link between a parent tenancy and a child tenancy.
    """

    #: A constant which can be used with the lifecycle_state property of a Link.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Link.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Link.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Link.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Link.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Link.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    def __init__(self, **kwargs):
        """
        Initializes a new Link object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Link.
        :type id: str

        :param parent_tenancy_id:
            The value to assign to the parent_tenancy_id property of this Link.
        :type parent_tenancy_id: str

        :param child_tenancy_id:
            The value to assign to the child_tenancy_id property of this Link.
        :type child_tenancy_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Link.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "FAILED", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this Link.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Link.
        :type time_updated: datetime

        :param time_terminated:
            The value to assign to the time_terminated property of this Link.
        :type time_terminated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'parent_tenancy_id': 'str',
            'child_tenancy_id': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'time_terminated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'parent_tenancy_id': 'parentTenancyId',
            'child_tenancy_id': 'childTenancyId',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'time_terminated': 'timeTerminated'
        }

        self._id = None
        self._parent_tenancy_id = None
        self._child_tenancy_id = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._time_terminated = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Link.
        OCID of the link.


        :return: The id of this Link.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Link.
        OCID of the link.


        :param id: The id of this Link.
        :type: str
        """
        self._id = id

    @property
    def parent_tenancy_id(self):
        """
        **[Required]** Gets the parent_tenancy_id of this Link.
        OCID of the parent tenancy.


        :return: The parent_tenancy_id of this Link.
        :rtype: str
        """
        return self._parent_tenancy_id

    @parent_tenancy_id.setter
    def parent_tenancy_id(self, parent_tenancy_id):
        """
        Sets the parent_tenancy_id of this Link.
        OCID of the parent tenancy.


        :param parent_tenancy_id: The parent_tenancy_id of this Link.
        :type: str
        """
        self._parent_tenancy_id = parent_tenancy_id

    @property
    def child_tenancy_id(self):
        """
        **[Required]** Gets the child_tenancy_id of this Link.
        OCID of the child tenancy


        :return: The child_tenancy_id of this Link.
        :rtype: str
        """
        return self._child_tenancy_id

    @child_tenancy_id.setter
    def child_tenancy_id(self, child_tenancy_id):
        """
        Sets the child_tenancy_id of this Link.
        OCID of the child tenancy


        :param child_tenancy_id: The child_tenancy_id of this Link.
        :type: str
        """
        self._child_tenancy_id = child_tenancy_id

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Link.
        Lifecycle state of the link.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "FAILED", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Link.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Link.
        Lifecycle state of the link.


        :param lifecycle_state: The lifecycle_state of this Link.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "FAILED", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Link.
        Date-time when this link was created.


        :return: The time_created of this Link.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Link.
        Date-time when this link was created.


        :param time_created: The time_created of this Link.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Link.
        Date-time when this link was last updated.


        :return: The time_updated of this Link.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Link.
        Date-time when this link was last updated.


        :param time_updated: The time_updated of this Link.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def time_terminated(self):
        """
        Gets the time_terminated of this Link.
        Date-time when this link was terminated.


        :return: The time_terminated of this Link.
        :rtype: datetime
        """
        return self._time_terminated

    @time_terminated.setter
    def time_terminated(self, time_terminated):
        """
        Sets the time_terminated of this Link.
        Date-time when this link was terminated.


        :param time_terminated: The time_terminated of this Link.
        :type: datetime
        """
        self._time_terminated = time_terminated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .config_source import ConfigSource
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CompartmentConfigSource(ConfigSource):
    """
    Compartment to use for creating the stack.
    The new stack will include definitions for supported resource types in this compartment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CompartmentConfigSource object with values from keyword arguments. The default value of the :py:attr:`~oci.resource_manager.models.CompartmentConfigSource.config_source_type` attribute
        of this class is ``COMPARTMENT_CONFIG_SOURCE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_source_type:
            The value to assign to the config_source_type property of this CompartmentConfigSource.
            Allowed values for this property are: "ZIP_UPLOAD", "GIT_CONFIG_SOURCE", "COMPARTMENT_CONFIG_SOURCE", "OBJECT_STORAGE_CONFIG_SOURCE"
        :type config_source_type: str

        :param working_directory:
            The value to assign to the working_directory property of this CompartmentConfigSource.
        :type working_directory: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CompartmentConfigSource.
        :type compartment_id: str

        :param region:
            The value to assign to the region property of this CompartmentConfigSource.
        :type region: str

        :param services_to_discover:
            The value to assign to the services_to_discover property of this CompartmentConfigSource.
        :type services_to_discover: list[str]

        """
        self.swagger_types = {
            'config_source_type': 'str',
            'working_directory': 'str',
            'compartment_id': 'str',
            'region': 'str',
            'services_to_discover': 'list[str]'
        }

        self.attribute_map = {
            'config_source_type': 'configSourceType',
            'working_directory': 'workingDirectory',
            'compartment_id': 'compartmentId',
            'region': 'region',
            'services_to_discover': 'servicesToDiscover'
        }

        self._config_source_type = None
        self._working_directory = None
        self._compartment_id = None
        self._region = None
        self._services_to_discover = None
        self._config_source_type = 'COMPARTMENT_CONFIG_SOURCE'

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CompartmentConfigSource.
        The `OCID`__ of the compartment to use
        for creating the stack. The new stack will include definitions for supported
        resource types in this compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CompartmentConfigSource.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CompartmentConfigSource.
        The `OCID`__ of the compartment to use
        for creating the stack. The new stack will include definitions for supported
        resource types in this compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CompartmentConfigSource.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def region(self):
        """
        **[Required]** Gets the region of this CompartmentConfigSource.
        The region to use for creating the stack. The new stack will include definitions for
        supported resource types in this region.


        :return: The region of this CompartmentConfigSource.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this CompartmentConfigSource.
        The region to use for creating the stack. The new stack will include definitions for
        supported resource types in this region.


        :param region: The region of this CompartmentConfigSource.
        :type: str
        """
        self._region = region

    @property
    def services_to_discover(self):
        """
        Gets the services_to_discover of this CompartmentConfigSource.
        Filter for `services to use with Resource Discovery`__.
        For example, \"database\" limits resource discovery to resource types within the Database service.
        The specified services must be in scope of the given compartment OCID (tenancy level for root compartment, compartment level otherwise).
        If not specified, then all services at the scope of the given compartment OCID are used.

        __ https://www.terraform.io/docs/providers/oci/guides/resource_discovery.html#services


        :return: The services_to_discover of this CompartmentConfigSource.
        :rtype: list[str]
        """
        return self._services_to_discover

    @services_to_discover.setter
    def services_to_discover(self, services_to_discover):
        """
        Sets the services_to_discover of this CompartmentConfigSource.
        Filter for `services to use with Resource Discovery`__.
        For example, \"database\" limits resource discovery to resource types within the Database service.
        The specified services must be in scope of the given compartment OCID (tenancy level for root compartment, compartment level otherwise).
        If not specified, then all services at the scope of the given compartment OCID are used.

        __ https://www.terraform.io/docs/providers/oci/guides/resource_discovery.html#services


        :param services_to_discover: The services_to_discover of this CompartmentConfigSource.
        :type: list[str]
        """
        self._services_to_discover = services_to_discover

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .ai_private_endpoint import AiPrivateEndpoint
from .ai_private_endpoint_collection import AiPrivateEndpointCollection
from .ai_private_endpoint_summary import AiPrivateEndpointSummary
from .anomaly import Anomaly
from .anomaly_detect_result import AnomalyDetectResult
from .change_ai_private_endpoint_compartment_details import ChangeAiPrivateEndpointCompartmentDetails
from .change_data_asset_compartment_details import ChangeDataAssetCompartmentDetails
from .change_model_compartment_details import ChangeModelCompartmentDetails
from .change_project_compartment_details import ChangeProjectCompartmentDetails
from .create_ai_private_endpoint_details import CreateAiPrivateEndpointDetails
from .create_data_asset_details import CreateDataAssetDetails
from .create_model_details import CreateModelDetails
from .create_project_details import CreateProjectDetails
from .data_asset import DataAsset
from .data_asset_collection import DataAssetCollection
from .data_asset_summary import DataAssetSummary
from .data_item import DataItem
from .data_source_details import DataSourceDetails
from .data_source_details_atp import DataSourceDetailsATP
from .data_source_details_influx import DataSourceDetailsInflux
from .data_source_details_object_storage import DataSourceDetailsObjectStorage
from .detect_anomalies_details import DetectAnomaliesDetails
from .detection_result_item import DetectionResultItem
from .embedded_detect_anomalies_request import EmbeddedDetectAnomaliesRequest
from .influx_details import InfluxDetails
from .influx_details_v1v8 import InfluxDetailsV1v8
from .influx_details_v2v0 import InfluxDetailsV2v0
from .inline_detect_anomalies_request import InlineDetectAnomaliesRequest
from .model import Model
from .model_collection import ModelCollection
from .model_summary import ModelSummary
from .model_training_details import ModelTrainingDetails
from .model_training_results import ModelTrainingResults
from .per_signal_details import PerSignalDetails
from .project import Project
from .project_collection import ProjectCollection
from .project_summary import ProjectSummary
from .row_reduction_details import RowReductionDetails
from .update_ai_private_endpoint_details import UpdateAiPrivateEndpointDetails
from .update_data_asset_details import UpdateDataAssetDetails
from .update_model_details import UpdateModelDetails
from .update_project_details import UpdateProjectDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for ai_anomaly_detection services.
ai_anomaly_detection_type_mapping = {
    "AiPrivateEndpoint": AiPrivateEndpoint,
    "AiPrivateEndpointCollection": AiPrivateEndpointCollection,
    "AiPrivateEndpointSummary": AiPrivateEndpointSummary,
    "Anomaly": Anomaly,
    "AnomalyDetectResult": AnomalyDetectResult,
    "ChangeAiPrivateEndpointCompartmentDetails": ChangeAiPrivateEndpointCompartmentDetails,
    "ChangeDataAssetCompartmentDetails": ChangeDataAssetCompartmentDetails,
    "ChangeModelCompartmentDetails": ChangeModelCompartmentDetails,
    "ChangeProjectCompartmentDetails": ChangeProjectCompartmentDetails,
    "CreateAiPrivateEndpointDetails": CreateAiPrivateEndpointDetails,
    "CreateDataAssetDetails": CreateDataAssetDetails,
    "CreateModelDetails": CreateModelDetails,
    "CreateProjectDetails": CreateProjectDetails,
    "DataAsset": DataAsset,
    "DataAssetCollection": DataAssetCollection,
    "DataAssetSummary": DataAssetSummary,
    "DataItem": DataItem,
    "DataSourceDetails": DataSourceDetails,
    "DataSourceDetailsATP": DataSourceDetailsATP,
    "DataSourceDetailsInflux": DataSourceDetailsInflux,
    "DataSourceDetailsObjectStorage": DataSourceDetailsObjectStorage,
    "DetectAnomaliesDetails": DetectAnomaliesDetails,
    "DetectionResultItem": DetectionResultItem,
    "EmbeddedDetectAnomaliesRequest": EmbeddedDetectAnomaliesRequest,
    "InfluxDetails": InfluxDetails,
    "InfluxDetailsV1v8": InfluxDetailsV1v8,
    "InfluxDetailsV2v0": InfluxDetailsV2v0,
    "InlineDetectAnomaliesRequest": InlineDetectAnomaliesRequest,
    "Model": Model,
    "ModelCollection": ModelCollection,
    "ModelSummary": ModelSummary,
    "ModelTrainingDetails": ModelTrainingDetails,
    "ModelTrainingResults": ModelTrainingResults,
    "PerSignalDetails": PerSignalDetails,
    "Project": Project,
    "ProjectCollection": ProjectCollection,
    "ProjectSummary": ProjectSummary,
    "RowReductionDetails": RowReductionDetails,
    "UpdateAiPrivateEndpointDetails": UpdateAiPrivateEndpointDetails,
    "UpdateDataAssetDetails": UpdateDataAssetDetails,
    "UpdateModelDetails": UpdateModelDetails,
    "UpdateProjectDetails": UpdateProjectDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_insight_summary import DatabaseInsightSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDatabaseInsightSummary(DatabaseInsightSummary):
    """
    Summary of a database insight resource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDatabaseInsightSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.AutonomousDatabaseInsightSummary.entity_source` attribute
        of this class is ``AUTONOMOUS_DATABASE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AutonomousDatabaseInsightSummary.
        :type id: str

        :param database_id:
            The value to assign to the database_id property of this AutonomousDatabaseInsightSummary.
        :type database_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this AutonomousDatabaseInsightSummary.
        :type compartment_id: str

        :param database_name:
            The value to assign to the database_name property of this AutonomousDatabaseInsightSummary.
        :type database_name: str

        :param database_display_name:
            The value to assign to the database_display_name property of this AutonomousDatabaseInsightSummary.
        :type database_display_name: str

        :param database_type:
            The value to assign to the database_type property of this AutonomousDatabaseInsightSummary.
        :type database_type: str

        :param database_version:
            The value to assign to the database_version property of this AutonomousDatabaseInsightSummary.
        :type database_version: str

        :param database_host_names:
            The value to assign to the database_host_names property of this AutonomousDatabaseInsightSummary.
        :type database_host_names: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AutonomousDatabaseInsightSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this AutonomousDatabaseInsightSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this AutonomousDatabaseInsightSummary.
        :type system_tags: dict(str, dict(str, object))

        :param entity_source:
            The value to assign to the entity_source property of this AutonomousDatabaseInsightSummary.
            Allowed values for this property are: "AUTONOMOUS_DATABASE", "EM_MANAGED_EXTERNAL_DATABASE", "MACS_MANAGED_EXTERNAL_DATABASE"
        :type entity_source: str

        :param processor_count:
            The value to assign to the processor_count property of this AutonomousDatabaseInsightSummary.
        :type processor_count: int

        :param status:
            The value to assign to the status property of this AutonomousDatabaseInsightSummary.
            Allowed values for this property are: "DISABLED", "ENABLED", "TERMINATED"
        :type status: str

        :param time_created:
            The value to assign to the time_created property of this AutonomousDatabaseInsightSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this AutonomousDatabaseInsightSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AutonomousDatabaseInsightSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "NEEDS_ATTENTION"
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this AutonomousDatabaseInsightSummary.
        :type lifecycle_details: str

        :param database_resource_type:
            The value to assign to the database_resource_type property of this AutonomousDatabaseInsightSummary.
        :type database_resource_type: str

        """
        self.swagger_types = {
            'id': 'str',
            'database_id': 'str',
            'compartment_id': 'str',
            'database_name': 'str',
            'database_display_name': 'str',
            'database_type': 'str',
            'database_version': 'str',
            'database_host_names': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'entity_source': 'str',
            'processor_count': 'int',
            'status': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'database_resource_type': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'database_id': 'databaseId',
            'compartment_id': 'compartmentId',
            'database_name': 'databaseName',
            'database_display_name': 'databaseDisplayName',
            'database_type': 'databaseType',
            'database_version': 'databaseVersion',
            'database_host_names': 'databaseHostNames',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'entity_source': 'entitySource',
            'processor_count': 'processorCount',
            'status': 'status',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'database_resource_type': 'databaseResourceType'
        }

        self._id = None
        self._database_id = None
        self._compartment_id = None
        self._database_name = None
        self._database_display_name = None
        self._database_type = None
        self._database_version = None
        self._database_host_names = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._entity_source = None
        self._processor_count = None
        self._status = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._database_resource_type = None
        self._entity_source = 'AUTONOMOUS_DATABASE'

    @property
    def database_resource_type(self):
        """
        Gets the database_resource_type of this AutonomousDatabaseInsightSummary.
        OCI database resource type


        :return: The database_resource_type of this AutonomousDatabaseInsightSummary.
        :rtype: str
        """
        return self._database_resource_type

    @database_resource_type.setter
    def database_resource_type(self, database_resource_type):
        """
        Sets the database_resource_type of this AutonomousDatabaseInsightSummary.
        OCI database resource type


        :param database_resource_type: The database_resource_type of this AutonomousDatabaseInsightSummary.
        :type: str
        """
        self._database_resource_type = database_resource_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlInsightAggregation(object):
    """
    Represents a SQL Insight.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlInsightAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param text:
            The value to assign to the text property of this SqlInsightAggregation.
        :type text: str

        :param values:
            The value to assign to the values property of this SqlInsightAggregation.
        :type values: list[int]

        :param category:
            The value to assign to the category property of this SqlInsightAggregation.
        :type category: str

        """
        self.swagger_types = {
            'text': 'str',
            'values': 'list[int]',
            'category': 'str'
        }

        self.attribute_map = {
            'text': 'text',
            'values': 'values',
            'category': 'category'
        }

        self._text = None
        self._values = None
        self._category = None

    @property
    def text(self):
        """
        **[Required]** Gets the text of this SqlInsightAggregation.
        Insight text.
        For example `Degrading SQLs`, `Variant SQLs`,
          `Inefficient SQLs`, `Improving SQLs`, `SQLs with Plan Changes`,
          `Degrading SQLs have increasing IO Time above 50%`,
          `Degrading SQLs are variant`,
          `2 of the 2 variant SQLs have plan changes`,
          `Inefficient SQLs have increasing CPU Time above 50%


        :return: The text of this SqlInsightAggregation.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this SqlInsightAggregation.
        Insight text.
        For example `Degrading SQLs`, `Variant SQLs`,
          `Inefficient SQLs`, `Improving SQLs`, `SQLs with Plan Changes`,
          `Degrading SQLs have increasing IO Time above 50%`,
          `Degrading SQLs are variant`,
          `2 of the 2 variant SQLs have plan changes`,
          `Inefficient SQLs have increasing CPU Time above 50%


        :param text: The text of this SqlInsightAggregation.
        :type: str
        """
        self._text = text

    @property
    def values(self):
        """
        **[Required]** Gets the values of this SqlInsightAggregation.
        SQL counts for a given insight. For example insight text `2 of 10 SQLs have degrading response time` will have values as [2,10]\"


        :return: The values of this SqlInsightAggregation.
        :rtype: list[int]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this SqlInsightAggregation.
        SQL counts for a given insight. For example insight text `2 of 10 SQLs have degrading response time` will have values as [2,10]\"


        :param values: The values of this SqlInsightAggregation.
        :type: list[int]
        """
        self._values = values

    @property
    def category(self):
        """
        **[Required]** Gets the category of this SqlInsightAggregation.
        Insight category. It would be one of the following
        DEGRADING,
        VARIANT,
        INEFFICIENT,
        CHANGING_PLANS,
        IMPROVING,
        DEGRADING_VARIANT,
        DEGRADING_INEFFICIENT,
        DEGRADING_CHANGING_PLANS,
        DEGRADING_INCREASING_IO,
        DEGRADING_INCREASING_CPU,
        DEGRADING_INCREASING_INEFFICIENT_WAIT,
        DEGRADING_CHANGING_PLANS_AND_INCREASING_IO,
        DEGRADING_CHANGING_PLANS_AND_INCREASING_CPU,
        DEGRADING_CHANGING_PLANS_AND_INCREASING_INEFFICIENT_WAIT,VARIANT_INEFFICIENT,
        VARIANT_CHANGING_PLANS,
        VARIANT_INCREASING_IO,
        VARIANT_INCREASING_CPU,
        VARIANT_INCREASING_INEFFICIENT_WAIT,
        VARIANT_CHANGING_PLANS_AND_INCREASING_IO,
        VARIANT_CHANGING_PLANS_AND_INCREASING_CPU,
        VARIANT_CHANGING_PLANS_AND_INCREASING_INEFFICIENT_WAIT,
        INEFFICIENT_CHANGING_PLANS,
        INEFFICIENT_INCREASING_INEFFICIENT_WAIT,
        INEFFICIENT_CHANGING_PLANS_AND_INCREASING_INEFFICIENT_WAIT


        :return: The category of this SqlInsightAggregation.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this SqlInsightAggregation.
        Insight category. It would be one of the following
        DEGRADING,
        VARIANT,
        INEFFICIENT,
        CHANGING_PLANS,
        IMPROVING,
        DEGRADING_VARIANT,
        DEGRADING_INEFFICIENT,
        DEGRADING_CHANGING_PLANS,
        DEGRADING_INCREASING_IO,
        DEGRADING_INCREASING_CPU,
        DEGRADING_INCREASING_INEFFICIENT_WAIT,
        DEGRADING_CHANGING_PLANS_AND_INCREASING_IO,
        DEGRADING_CHANGING_PLANS_AND_INCREASING_CPU,
        DEGRADING_CHANGING_PLANS_AND_INCREASING_INEFFICIENT_WAIT,VARIANT_INEFFICIENT,
        VARIANT_CHANGING_PLANS,
        VARIANT_INCREASING_IO,
        VARIANT_INCREASING_CPU,
        VARIANT_INCREASING_INEFFICIENT_WAIT,
        VARIANT_CHANGING_PLANS_AND_INCREASING_IO,
        VARIANT_CHANGING_PLANS_AND_INCREASING_CPU,
        VARIANT_CHANGING_PLANS_AND_INCREASING_INEFFICIENT_WAIT,
        INEFFICIENT_CHANGING_PLANS,
        INEFFICIENT_INCREASING_INEFFICIENT_WAIT,
        INEFFICIENT_CHANGING_PLANS_AND_INCREASING_INEFFICIENT_WAIT


        :param category: The category of this SqlInsightAggregation.
        :type: str
        """
        self._category = category

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HeatWaveClusterMemoryEstimate(object):
    """
    HeatWave cluster memory estimate
    that can be used to determine a suitable HeatWave cluster size. For each MySQL user table the estimated memory
    footprint when the table is loaded to the HeatWave cluster memory is returned.
    """

    #: A constant which can be used with the status property of a HeatWaveClusterMemoryEstimate.
    #: This constant has a value of "ACCEPTED"
    STATUS_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the status property of a HeatWaveClusterMemoryEstimate.
    #: This constant has a value of "IN_PROGRESS"
    STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the status property of a HeatWaveClusterMemoryEstimate.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    #: A constant which can be used with the status property of a HeatWaveClusterMemoryEstimate.
    #: This constant has a value of "SUCCEEDED"
    STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the status property of a HeatWaveClusterMemoryEstimate.
    #: This constant has a value of "CANCELING"
    STATUS_CANCELING = "CANCELING"

    #: A constant which can be used with the status property of a HeatWaveClusterMemoryEstimate.
    #: This constant has a value of "CANCELED"
    STATUS_CANCELED = "CANCELED"

    def __init__(self, **kwargs):
        """
        Initializes a new HeatWaveClusterMemoryEstimate object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param db_system_id:
            The value to assign to the db_system_id property of this HeatWaveClusterMemoryEstimate.
        :type db_system_id: str

        :param status:
            The value to assign to the status property of this HeatWaveClusterMemoryEstimate.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param time_created:
            The value to assign to the time_created property of this HeatWaveClusterMemoryEstimate.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this HeatWaveClusterMemoryEstimate.
        :type time_updated: datetime

        :param table_schemas:
            The value to assign to the table_schemas property of this HeatWaveClusterMemoryEstimate.
        :type table_schemas: list[oci.mysql.models.HeatWaveClusterSchemaMemoryEstimate]

        """
        self.swagger_types = {
            'db_system_id': 'str',
            'status': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'table_schemas': 'list[HeatWaveClusterSchemaMemoryEstimate]'
        }

        self.attribute_map = {
            'db_system_id': 'dbSystemId',
            'status': 'status',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'table_schemas': 'tableSchemas'
        }

        self._db_system_id = None
        self._status = None
        self._time_created = None
        self._time_updated = None
        self._table_schemas = None

    @property
    def db_system_id(self):
        """
        **[Required]** Gets the db_system_id of this HeatWaveClusterMemoryEstimate.
        The OCID of the DB System the HeatWave cluster memory estimate is associated with.


        :return: The db_system_id of this HeatWaveClusterMemoryEstimate.
        :rtype: str
        """
        return self._db_system_id

    @db_system_id.setter
    def db_system_id(self, db_system_id):
        """
        Sets the db_system_id of this HeatWaveClusterMemoryEstimate.
        The OCID of the DB System the HeatWave cluster memory estimate is associated with.


        :param db_system_id: The db_system_id of this HeatWaveClusterMemoryEstimate.
        :type: str
        """
        self._db_system_id = db_system_id

    @property
    def status(self):
        """
        **[Required]** Gets the status of this HeatWaveClusterMemoryEstimate.
        Current status of the Work Request generating the HeatWave cluster memory estimate.

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this HeatWaveClusterMemoryEstimate.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this HeatWaveClusterMemoryEstimate.
        Current status of the Work Request generating the HeatWave cluster memory estimate.


        :param status: The status of this HeatWaveClusterMemoryEstimate.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this HeatWaveClusterMemoryEstimate.
        The date and time that the Work Request to generate the HeatWave cluster memory estimate was issued, as described by `RFC 3339`__.

        __ https://tools.ietf.org/rfc/rfc333


        :return: The time_created of this HeatWaveClusterMemoryEstimate.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this HeatWaveClusterMemoryEstimate.
        The date and time that the Work Request to generate the HeatWave cluster memory estimate was issued, as described by `RFC 3339`__.

        __ https://tools.ietf.org/rfc/rfc333


        :param time_created: The time_created of this HeatWaveClusterMemoryEstimate.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this HeatWaveClusterMemoryEstimate.
        The date and time that the HeatWave cluster memory estimate was generated, as described by `RFC 3339`__.

        __ https://tools.ietf.org/rfc/rfc333


        :return: The time_updated of this HeatWaveClusterMemoryEstimate.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this HeatWaveClusterMemoryEstimate.
        The date and time that the HeatWave cluster memory estimate was generated, as described by `RFC 3339`__.

        __ https://tools.ietf.org/rfc/rfc333


        :param time_updated: The time_updated of this HeatWaveClusterMemoryEstimate.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def table_schemas(self):
        """
        **[Required]** Gets the table_schemas of this HeatWaveClusterMemoryEstimate.
        Collection of schemas with estimated memory footprints for MySQL user tables of each schema
        when loaded to HeatWave cluster memory.


        :return: The table_schemas of this HeatWaveClusterMemoryEstimate.
        :rtype: list[oci.mysql.models.HeatWaveClusterSchemaMemoryEstimate]
        """
        return self._table_schemas

    @table_schemas.setter
    def table_schemas(self, table_schemas):
        """
        Sets the table_schemas of this HeatWaveClusterMemoryEstimate.
        Collection of schemas with estimated memory footprints for MySQL user tables of each schema
        when loaded to HeatWave cluster memory.


        :param table_schemas: The table_schemas of this HeatWaveClusterMemoryEstimate.
        :type: list[oci.mysql.models.HeatWaveClusterSchemaMemoryEstimate]
        """
        self._table_schemas = table_schemas

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StructuredType(object):
    """
    A `StructuredType` object represents a data type that exists in a physical data asset object such as a table column, but is more complex. For example, an Oracle database `OBJECT` type. It can be composed of multiple `DataType` objects.
    """

    #: A constant which can be used with the dt_type property of a StructuredType.
    #: This constant has a value of "PRIMITIVE"
    DT_TYPE_PRIMITIVE = "PRIMITIVE"

    #: A constant which can be used with the dt_type property of a StructuredType.
    #: This constant has a value of "STRUCTURED"
    DT_TYPE_STRUCTURED = "STRUCTURED"

    def __init__(self, **kwargs):
        """
        Initializes a new StructuredType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param schema:
            The value to assign to the schema property of this StructuredType.
        :type schema: oci.data_integration.models.BaseType

        :param dt_type:
            The value to assign to the dt_type property of this StructuredType.
            Allowed values for this property are: "PRIMITIVE", "STRUCTURED"
        :type dt_type: str

        :param type_system_name:
            The value to assign to the type_system_name property of this StructuredType.
        :type type_system_name: str

        :param config_definition:
            The value to assign to the config_definition property of this StructuredType.
        :type config_definition: oci.data_integration.models.ConfigDefinition

        """
        self.swagger_types = {
            'schema': 'BaseType',
            'dt_type': 'str',
            'type_system_name': 'str',
            'config_definition': 'ConfigDefinition'
        }

        self.attribute_map = {
            'schema': 'schema',
            'dt_type': 'dtType',
            'type_system_name': 'typeSystemName',
            'config_definition': 'configDefinition'
        }

        self._schema = None
        self._dt_type = None
        self._type_system_name = None
        self._config_definition = None

    @property
    def schema(self):
        """
        Gets the schema of this StructuredType.

        :return: The schema of this StructuredType.
        :rtype: oci.data_integration.models.BaseType
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """
        Sets the schema of this StructuredType.

        :param schema: The schema of this StructuredType.
        :type: oci.data_integration.models.BaseType
        """
        self._schema = schema

    @property
    def dt_type(self):
        """
        Gets the dt_type of this StructuredType.
        The data type.

        Allowed values for this property are: "PRIMITIVE", "STRUCTURED"


        :return: The dt_type of this StructuredType.
        :rtype: str
        """
        return self._dt_type

    @dt_type.setter
    def dt_type(self, dt_type):
        """
        Sets the dt_type of this StructuredType.
        The data type.


        :param dt_type: The dt_type of this StructuredType.
        :type: str
        """
        allowed_values = ["PRIMITIVE", "STRUCTURED"]
        if not value_allowed_none_or_none_sentinel(dt_type, allowed_values):
            raise ValueError(
                "Invalid value for `dt_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._dt_type = dt_type

    @property
    def type_system_name(self):
        """
        Gets the type_system_name of this StructuredType.
        The data type system name.


        :return: The type_system_name of this StructuredType.
        :rtype: str
        """
        return self._type_system_name

    @type_system_name.setter
    def type_system_name(self, type_system_name):
        """
        Sets the type_system_name of this StructuredType.
        The data type system name.


        :param type_system_name: The type_system_name of this StructuredType.
        :type: str
        """
        self._type_system_name = type_system_name

    @property
    def config_definition(self):
        """
        Gets the config_definition of this StructuredType.

        :return: The config_definition of this StructuredType.
        :rtype: oci.data_integration.models.ConfigDefinition
        """
        return self._config_definition

    @config_definition.setter
    def config_definition(self, config_definition):
        """
        Sets the config_definition of this StructuredType.

        :param config_definition: The config_definition of this StructuredType.
        :type: oci.data_integration.models.ConfigDefinition
        """
        self._config_definition = config_definition

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ViewSummary(object):
    """
    An OCI DNS view.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the lifecycle_state property of a ViewSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ViewSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ViewSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ViewSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new ViewSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this ViewSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this ViewSummary.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ViewSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ViewSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param id:
            The value to assign to the id property of this ViewSummary.
        :type id: str

        :param _self:
            The value to assign to the _self property of this ViewSummary.
        :type _self: str

        :param time_created:
            The value to assign to the time_created property of this ViewSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ViewSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ViewSummary.
            Allowed values for this property are: "ACTIVE", "DELETED", "DELETING", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param is_protected:
            The value to assign to the is_protected property of this ViewSummary.
        :type is_protected: bool

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'id': 'str',
            '_self': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'is_protected': 'bool'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'id': 'id',
            '_self': 'self',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'is_protected': 'isProtected'
        }

        self._compartment_id = None
        self._display_name = None
        self._freeform_tags = None
        self._defined_tags = None
        self._id = None
        self.__self = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._is_protected = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ViewSummary.
        The OCID of the owning compartment.


        :return: The compartment_id of this ViewSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ViewSummary.
        The OCID of the owning compartment.


        :param compartment_id: The compartment_id of this ViewSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ViewSummary.
        The display name of the view.


        :return: The display_name of this ViewSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ViewSummary.
        The display name of the view.


        :param display_name: The display_name of this ViewSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        **[Required]** Gets the freeform_tags of this ViewSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ViewSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ViewSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ViewSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        **[Required]** Gets the defined_tags of this ViewSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ViewSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ViewSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ViewSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ViewSummary.
        The OCID of the view.


        :return: The id of this ViewSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ViewSummary.
        The OCID of the view.


        :param id: The id of this ViewSummary.
        :type: str
        """
        self._id = id

    @property
    def _self(self):
        """
        **[Required]** Gets the _self of this ViewSummary.
        The canonical absolute URL of the resource.


        :return: The _self of this ViewSummary.
        :rtype: str
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """
        Sets the _self of this ViewSummary.
        The canonical absolute URL of the resource.


        :param _self: The _self of this ViewSummary.
        :type: str
        """
        self.__self = _self

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ViewSummary.
        The date and time the resource was created in \"YYYY-MM-ddThh:mm:ssZ\" format
        with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :return: The time_created of this ViewSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ViewSummary.
        The date and time the resource was created in \"YYYY-MM-ddThh:mm:ssZ\" format
        with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :param time_created: The time_created of this ViewSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this ViewSummary.
        The date and time the resource was last updated in \"YYYY-MM-ddThh:mm:ssZ\"
        format with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :return: The time_updated of this ViewSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ViewSummary.
        The date and time the resource was last updated in \"YYYY-MM-ddThh:mm:ssZ\"
        format with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :param time_updated: The time_updated of this ViewSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ViewSummary.
        The current state of the resource.

        Allowed values for this property are: "ACTIVE", "DELETED", "DELETING", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ViewSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ViewSummary.
        The current state of the resource.


        :param lifecycle_state: The lifecycle_state of this ViewSummary.
        :type: str
        """
        allowed_values = ["ACTIVE", "DELETED", "DELETING", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def is_protected(self):
        """
        **[Required]** Gets the is_protected of this ViewSummary.
        A Boolean flag indicating whether or not parts of the resource are unable to be explicitly managed.


        :return: The is_protected of this ViewSummary.
        :rtype: bool
        """
        return self._is_protected

    @is_protected.setter
    def is_protected(self, is_protected):
        """
        Sets the is_protected of this ViewSummary.
        A Boolean flag indicating whether or not parts of the resource are unable to be explicitly managed.


        :param is_protected: The is_protected of this ViewSummary.
        :type: bool
        """
        self._is_protected = is_protected

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlPlanSummary(object):
    """
    SQL Plan details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlPlanSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param plan_hash:
            The value to assign to the plan_hash property of this SqlPlanSummary.
        :type plan_hash: int

        :param plan_content:
            The value to assign to the plan_content property of this SqlPlanSummary.
        :type plan_content: str

        """
        self.swagger_types = {
            'plan_hash': 'int',
            'plan_content': 'str'
        }

        self.attribute_map = {
            'plan_hash': 'planHash',
            'plan_content': 'planContent'
        }

        self._plan_hash = None
        self._plan_content = None

    @property
    def plan_hash(self):
        """
        **[Required]** Gets the plan_hash of this SqlPlanSummary.
        Plan hash value for the SQL Execution Plan


        :return: The plan_hash of this SqlPlanSummary.
        :rtype: int
        """
        return self._plan_hash

    @plan_hash.setter
    def plan_hash(self, plan_hash):
        """
        Sets the plan_hash of this SqlPlanSummary.
        Plan hash value for the SQL Execution Plan


        :param plan_hash: The plan_hash of this SqlPlanSummary.
        :type: int
        """
        self._plan_hash = plan_hash

    @property
    def plan_content(self):
        """
        **[Required]** Gets the plan_content of this SqlPlanSummary.
        Plan XML Content


        :return: The plan_content of this SqlPlanSummary.
        :rtype: str
        """
        return self._plan_content

    @plan_content.setter
    def plan_content(self, plan_content):
        """
        Sets the plan_content of this SqlPlanSummary.
        Plan XML Content


        :param plan_content: The plan_content of this SqlPlanSummary.
        :type: str
        """
        self._plan_content = plan_content

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ModelTrainingResults(object):
    """
    Specifies the details for an Anomaly Detection model trained with MSET.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ModelTrainingResults object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param fap:
            The value to assign to the fap property of this ModelTrainingResults.
        :type fap: float

        :param multivariate_fap:
            The value to assign to the multivariate_fap property of this ModelTrainingResults.
        :type multivariate_fap: float

        :param is_training_goal_achieved:
            The value to assign to the is_training_goal_achieved property of this ModelTrainingResults.
        :type is_training_goal_achieved: bool

        :param warning:
            The value to assign to the warning property of this ModelTrainingResults.
        :type warning: str

        :param signal_details:
            The value to assign to the signal_details property of this ModelTrainingResults.
        :type signal_details: list[oci.ai_anomaly_detection.models.PerSignalDetails]

        :param row_reduction_details:
            The value to assign to the row_reduction_details property of this ModelTrainingResults.
        :type row_reduction_details: oci.ai_anomaly_detection.models.RowReductionDetails

        """
        self.swagger_types = {
            'fap': 'float',
            'multivariate_fap': 'float',
            'is_training_goal_achieved': 'bool',
            'warning': 'str',
            'signal_details': 'list[PerSignalDetails]',
            'row_reduction_details': 'RowReductionDetails'
        }

        self.attribute_map = {
            'fap': 'fap',
            'multivariate_fap': 'multivariateFap',
            'is_training_goal_achieved': 'isTrainingGoalAchieved',
            'warning': 'warning',
            'signal_details': 'signalDetails',
            'row_reduction_details': 'rowReductionDetails'
        }

        self._fap = None
        self._multivariate_fap = None
        self._is_training_goal_achieved = None
        self._warning = None
        self._signal_details = None
        self._row_reduction_details = None

    @property
    def fap(self):
        """
        **[Required]** Gets the fap of this ModelTrainingResults.
        The final-achieved model accuracy metric on individual value level


        :return: The fap of this ModelTrainingResults.
        :rtype: float
        """
        return self._fap

    @fap.setter
    def fap(self, fap):
        """
        Sets the fap of this ModelTrainingResults.
        The final-achieved model accuracy metric on individual value level


        :param fap: The fap of this ModelTrainingResults.
        :type: float
        """
        self._fap = fap

    @property
    def multivariate_fap(self):
        """
        Gets the multivariate_fap of this ModelTrainingResults.
        The model accuracy metric on timestamp level.


        :return: The multivariate_fap of this ModelTrainingResults.
        :rtype: float
        """
        return self._multivariate_fap

    @multivariate_fap.setter
    def multivariate_fap(self, multivariate_fap):
        """
        Sets the multivariate_fap of this ModelTrainingResults.
        The model accuracy metric on timestamp level.


        :param multivariate_fap: The multivariate_fap of this ModelTrainingResults.
        :type: float
        """
        self._multivariate_fap = multivariate_fap

    @property
    def is_training_goal_achieved(self):
        """
        Gets the is_training_goal_achieved of this ModelTrainingResults.
        A boolean value to indicate if train goal/targetFap is achieved for trained model


        :return: The is_training_goal_achieved of this ModelTrainingResults.
        :rtype: bool
        """
        return self._is_training_goal_achieved

    @is_training_goal_achieved.setter
    def is_training_goal_achieved(self, is_training_goal_achieved):
        """
        Sets the is_training_goal_achieved of this ModelTrainingResults.
        A boolean value to indicate if train goal/targetFap is achieved for trained model


        :param is_training_goal_achieved: The is_training_goal_achieved of this ModelTrainingResults.
        :type: bool
        """
        self._is_training_goal_achieved = is_training_goal_achieved

    @property
    def warning(self):
        """
        Gets the warning of this ModelTrainingResults.
        A warning message to explain the reason when targetFap cannot be achieved for trained model


        :return: The warning of this ModelTrainingResults.
        :rtype: str
        """
        return self._warning

    @warning.setter
    def warning(self, warning):
        """
        Sets the warning of this ModelTrainingResults.
        A warning message to explain the reason when targetFap cannot be achieved for trained model


        :param warning: The warning of this ModelTrainingResults.
        :type: str
        """
        self._warning = warning

    @property
    def signal_details(self):
        """
        Gets the signal_details of this ModelTrainingResults.
        The list of signal details.


        :return: The signal_details of this ModelTrainingResults.
        :rtype: list[oci.ai_anomaly_detection.models.PerSignalDetails]
        """
        return self._signal_details

    @signal_details.setter
    def signal_details(self, signal_details):
        """
        Sets the signal_details of this ModelTrainingResults.
        The list of signal details.


        :param signal_details: The signal_details of this ModelTrainingResults.
        :type: list[oci.ai_anomaly_detection.models.PerSignalDetails]
        """
        self._signal_details = signal_details

    @property
    def row_reduction_details(self):
        """
        Gets the row_reduction_details of this ModelTrainingResults.

        :return: The row_reduction_details of this ModelTrainingResults.
        :rtype: oci.ai_anomaly_detection.models.RowReductionDetails
        """
        return self._row_reduction_details

    @row_reduction_details.setter
    def row_reduction_details(self, row_reduction_details):
        """
        Sets the row_reduction_details of this ModelTrainingResults.

        :param row_reduction_details: The row_reduction_details of this ModelTrainingResults.
        :type: oci.ai_anomaly_detection.models.RowReductionDetails
        """
        self._row_reduction_details = row_reduction_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
